@@ -8,18 +8,22 @@ use Exporter qw(import);
 
 =head1 NAME
 
-Text::CSV::Easy - easy csv parsing and building
+Text::CSV::Easy - Easy CSV parsing and building
 
 =head1 VERSION
 
-Version 0.03
+Version 0.05
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 our @EXPORT_OK = qw(csv_build csv_parse);
 
+# used to ensure XS and PP stay in sync.
+our $TCE_VERSION;
+BEGIN { $TCE_VERSION = 1 }
+
 =head1 SYNOPSIS
 
  use Text::CSV::Easy qw( csv_build csv_parse );
@@ -51,7 +55,7 @@ my $MODULE;
 
 BEGIN {
     my $xs_loaded = eval { require Text::CSV::Easy_XS; 1 };
-    if ($xs_loaded) {
+    if ( $xs_loaded && $Text::CSV::Easy_XS::TCE_VERSION == $TCE_VERSION ) {
         $MODULE = 'Text::CSV::Easy_XS';
     }
     else {
